@@ -1,6 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Schedule;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Reports::Web::Controller::Tapper::Schedule::VERSION = '5.0.1';
+$Tapper::Reports::Web::Controller::Tapper::Schedule::VERSION = '5.0.2';
 use strict;
 use warnings;
 use parent 'Catalyst::Controller';
@@ -11,7 +11,7 @@ use parent 'Catalyst::Controller';
 sub index :Path :Args(0) {
     my ( $self, $c ) = @_;
 
-    my $body = qx(tapper-testrun listqueue -v);
+    my $body = qx(tapper queue-list -v);
 
     $c->response->body("<pre>
 $body
